Installation
============

- From PyPI::

      pip install sshuttle

- Debain package manager::
		sudo apt install sshuttle

- Clone::

      git clone https://github.com/sshuttle/sshuttle.git
      cd sshuttle
      ./setup.py install


Optionally after installation
-----------------------------

- Add to sudoers file
		sshuttle --sudoers
